@@ -10,8 +10,8 @@ from gcloud.aio.datastore import value
 
 
 # https://cloud.google.com/datastore/docs/reference/data/rest/v1/projects/runQuery#ArrayValue
-class Array(Sequence):
-    def __init__(self, items: List[Any]) -> None:
+class Array(Sequence):  # type: ignore[type-arg]
+    def __init__(self, items: List[value.Value]) -> None:
         super(Sequence, self).__init__()  # pylint: disable=bad-super-call
         self.items = items
 
